<?php

/*------------------------------------------------------------------------
# com_invoices - Invoices for Joomla
# ------------------------------------------------------------------------
# author				Germinal Camps
# copyright 			Copyright (C) 2013 JoomlaThat.com. All Rights Reserved.
# @license				http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
# Websites: 			http://www.JoomlaThat.com
# Technical Support:	Forum - http://www.JoomlaThat.com/support
-------------------------------------------------------------------------*/

/** ensure this file is being included by a parent file */
defined('_JEXEC') or die('Restricted access');

jimport('joomla.plugin.plugin');


class plgInvoicesPayment_authorizenet extends JPlugin {

	var $_payment_type = 'payment_authorizenet';

	function plgInvoicesPayment_authorizenet(& $subject, $config) {

		parent::__construct($subject, $config);
		$this->loadLanguage( '', JPATH_ADMINISTRATOR );

	}

	function update_payment($payment){

		$model = $this->getPaymentsModel();
		$model->store(get_object_vars($payment));

	}

	private function getPaymentsModel()
	{
		if (!class_exists( 'PaymentsModelPayment' ))
		{
			// Build the path to the model based upon a supplied base path
			$path = JPATH_SITE.DS.'administrator'.DS.'components'.DS.'com_invoices'.DS.'models'.DS.'payment.php';
			$false = false;

			// If the model file exists include it and try to instantiate the object
			if (file_exists( $path )) {
				require_once( $path );
				if (!class_exists( 'PaymentsModelPayment' )) {
					JError::raiseWarning( 0, 'Model class PaymentsModelPayment not found in file.' );
					return $false;
				}
			} else {
				JError::raiseWarning( 0, 'Model PaymentsModelPayment not supported. File not found.' );
				return $false;
			}
		}

		$model = new PaymentsModelPayment();
		return $model;
	}

	function _logData($data)
	{
		$f = fopen(JPATH_CACHE . '/invoices_authorize.txt', 'a');
		fwrite($f, "\n" . date('F j, Y, g:i a') . "\n");
		fwrite($f, print_r($data, true));
		fclose($f);
	}

	function onRenderPaymentOptions( $row, $user )
	{

		$rootURL = rtrim(JURI::base(),'/');
		$subpathURL = JURI::base(true);
		if(!empty($subpathURL) && ($subpathURL != '/')) {
			$rootURL = substr($rootURL, 0, -1 * strlen($subpathURL));
		}

		if($this->params->get('sandbox',0)) $url = 'https://test.authorize.net/gateway/transact.dll' ;
		else $url = 'https://secure2.authorize.net/gateway/transact.dll' ;

		$parts = explode(" ", $row->to_name);
		$lastname = trim(array_pop($parts));
		$firstname = trim(implode(" ", $parts));

		$data = (object)array(
			'url' => $url,
			'x_version'				=> '3.1',
			'x_type'				=> 'AUTH_CAPTURE',
			'x_login'				=> trim($this->params->get('api','')),
			'x_amount'				=> sprintf('%.2f',$row->payment_amount),
			/*'x_tax'					=> sprintf('%.2f',$row->payment_amount),*/
			'x_currency_code'		=> strtoupper($this->params->get( 'currency', 'USD' )),
			'x_description'			=> $row->payment_description,
			'x_invoice_num'			=> $row->invoice_num,
			'x_fp_sequence'			=> $row->invoice_id,
			'x_fp_timestamp'		=> time(),
			'x_test_request'		=> $this->params->get('sandbox',0),
			'x_show_form'			=> 'PAYMENT_FORM',
			'x_first_name'			=> $firstname,
			'x_last_name'			=> $lastname,
			'x_address'				=> trim($row->to_address),
			'x_city'				=> trim($row->to_city),
			'x_zip'					=> trim($row->to_zipcode),
			'x_country'				=> trim($row->to_country),
			'x_email'				=> trim($row->to_email),
			'x_phone'				=> trim($row->to_phone),
			'x_cancel_url'			=> $rootURL.str_replace('&amp;','&',JRoute::_('index.php?option=com_invoices&task=process_payment&ptype='.$this->_payment_type.'&paction=display_message&item_number='.$row->id)),
			'x_relay_response'		=> 'TRUE',
			'x_relay_url'			=> JURI::base().'index.php?option=com_invoices&task=process_payment&ptype='.$this->_payment_type.'&paction=process&tmpl=component&item_number='.$row->id
		);

		$data->note = $this->params->get( 'description' ) ;

		$state = trim($row->to_state);
		if(!empty($state)) {
			$data->x_state = $state;
		}

		if($row->to_company) {
			$data->x_company = trim($row->to_company);
		}

		$transactionKey = trim($this->params->get('key',''));
		$data->x_fp_hash = $this->getFingerprint(
				$data->x_login,
				$transactionKey,
				$data->x_amount,
				$data->x_fp_sequence,
				$data->x_fp_timestamp,
				$data->x_currency_code
			);

		$html = $this->_getLayout('form', $data);

		$text = array();
		$text[] = $html;
		$text[] = $this->params->get( 'title', 'Authorize.Net' );

		return $text;
	}

	private function getFingerprint($apiLoginId, $transactionKey, $amount, $sequence, $timestamp, $currencyCode)
    {
        if(function_exists('hash_hmac')) {
            return hash_hmac("md5", $apiLoginId . "^" . $sequence . "^" . $timestamp . "^" . $amount . "^" . $currencyCode, $transactionKey);
        }
        return bin2hex(mhash(MHASH_MD5, $apiLoginId . "^" . $sequence . "^" . $timestamp . "^" . $amount . "^" . $currencyCode, $transactionKey));
    }

	function onProcessPayment( $row, $user )
	{
		$ptype 		= JRequest::getVar( 'ptype' );

		$app =& JFactory::getApplication();

		if ($ptype == $this->_payment_type)
		{
			$paction 	= JRequest::getVar( 'paction' );
			$html = "";

			switch ($paction) {
				case "display_message":

				  break;
				case "process":

					$html .= $this->_process();

					//$app->redirect('index.php?option=com_invoices&task=process_payment&ptype='.$this->_payment_type.'&paction=display_message&tmpl=component&item_number='.$row->id);

				  break;
				case "cancel":

				  break;
				default:

				  break;
			}

			return $html;
		}

	}

	function _process()
	{
		$app = JFactory::getApplication();

		$data = JRequest::get('post');
		$errors = array();

		$this->_logData($data);
/*
		[x_response_code] => 1
	    [x_response_reason_code] => 1
	    [x_response_reason_text] => (TESTMODE) This transaction has been approved.
	    [x_avs_code] => P
	    [x_auth_code] => 000000
	    [x_trans_id] => 0
	    [x_method] => CC
	    [x_card_type] => Visa
	    [x_account_number] => XXXX0027
	    [x_first_name] => Testing germi
	    [x_last_name] =>
	    [x_company] => 31/12/12100
	    [x_address] => asdfasdf
	    [x_city] => Barcelona
	    [x_state] => Barcelona
	    [x_zip] => 08001
	    [x_country] => España
	    [x_phone] =>
	    [x_fax] =>
	    [x_email] => gcampsbarjau@gmail.com
	    [x_invoice_num] => 11
	    [x_description] =>
	    [x_type] => auth_capture
	    [x_cust_id] =>
	    [x_ship_to_first_name] => Testing germi
	    [x_ship_to_last_name] =>
	    [x_ship_to_company] => 31/12/12100
	    [x_ship_to_address] => asdfasdf
	    [x_ship_to_city] => Barcelona
	    [x_ship_to_state] => Barcelona
	    [x_ship_to_zip] => 08001
	    [x_ship_to_country] => España
	    [x_amount] => 1.00
	    [x_tax] => 0.00
	    [x_duty] => 0.00
	    [x_freight] => 0.00
	    [x_tax_exempt] => FALSE
	    [x_po_num] =>
	    [x_MD5_Hash] => 2DB5C2F012B8FE327B5B9BE3CE992D6A
	    [x_cvv2_resp_code] =>
	    [x_cavv_response] =>
	    [x_test_request] => true
	    [x_method_available] => true
	*/

	    //we load the payment
	    $data["payment_id"] = (int) $data["x_invoice_num"];

	    $data["payment_id"] = JRequest::getInt('item_number');

		$payment = InvoicesHelper::getPaymentData($data['payment_id']);

		$isValid = false ;
		// prepare some data

		$payment_details = $this->_getFormattedPaymentDetails($data);

		$mc_gross = floatval($data['x_amount']);
		$gross = $payment->payment_amount;
		if($mc_gross > 0) {
			// A positive value means "payment". The prices MUST match!
			// Important: NEVER, EVER compare two floating point values for equality.
			$isValid = ($gross - $mc_gross) < 0.01;
		}

		// Check the payment_status
		switch($data['x_response_code']) {
			case 1:
				$payment->payment_status = 1; // paid
				break;
			case 4:
				$payment->payment_status = 2; // pending
				break;
			default:
				$payment->payment_status = 0; //unpaid
				break;
		}

		if(!$isValid) $payment->payment_status = 0 ;

		$payment->payment_type = $this->_payment_type;
		$payment->payment_details = $payment_details;
		$payment->payment_datetime = date("Y-m-d H:i:s");
		$payment->payment_id = $data['x_trans_id'] ;

		$this->update_payment($payment);

		$app->enqueueMessage($data['x_response_reason_text']);

	}

    function _getParam($name, $default = '')
    {
    	$sandbox_param = "sandbox_$name";
    	$sb_value = $this->params->get($sandbox_param);

        if ($this->params->get('sandbox') && !empty($sb_value)) {
            $param = $this->params->get($sandbox_param, $default);
        }
        else {
        	$param = $this->params->get($name, $default);
        }

        return $param;
    }


	function _getLayout($layout, $data = false, $plugin = '', $group = 'invoices')
	{
		if ( ! $plugin) {
			$plugin = $this->_payment_type;
		}

		ob_start();
        $layout = $this->_getLayoutPath( $plugin, $group, $layout );
        include($layout);
        $html = ob_get_contents();
        ob_end_clean();

		return $html;
	}


    function _getLayoutPath($plugin, $group, $layout = 'default')
    {
        $app = JFactory::getApplication();

        // get the template and default paths for the layout
        $templatePath = JPATH_BASE.DS.'templates'.DS.$app->getTemplate().DS.'html'.DS.'plugins'.DS.$group.DS.$plugin.DS.$plugin.DS.$layout.'.php';
        $defaultPath = JPATH_BASE.DS.'plugins'.DS.$group.DS.$plugin.DS.$plugin.DS.'tmpl'.DS.$layout.'.php';

        // if the site template has a layout override, use it
        jimport('joomla.filesystem.file');
        if (JFile::exists( $templatePath ))
        {
            return $templatePath;
        }
        else
        {
            return $defaultPath;
        }
    }


	function _getFormattedPaymentDetails($data)
	{
		$separator = "\n";
		$formatted = array();

		foreach ($data as $key => $value) {
			if ($key != 'view' && $key != 'layout' && $key != 'custom') {
				$formatted[] = $key . ' = ' . $value;
			}
		}

		return count($formatted) ? implode("\n", $formatted) : '';
	}

}
